@@ -1,8 +1,8 @@
 import autoBOTLib
-from autoBOTLib.optimization_utils import *
-from autoBOTLib.optimization_feature_constructors import *
-from autoBOTLib.optimization_engine import *
-from autoBOTLib.misc_helpers import *
+from autoBOTLib.optimization.optimization_utils import *
+from autoBOTLib.optimization.optimization_feature_constructors import *
+from autoBOTLib.optimization.optimization_engine import *
+from autoBOTLib.misc.misc_helpers import *
 
 import logging
 logging.basicConfig(format='%(asctime)s - %(message)s',
