@@ -18,6 +18,7 @@ from autoBOTLib.features.features_concepts import *
 from autoBOTLib.features.features_keyword import *
 from autoBOTLib.features.features_sentence_embeddings import *
 from autoBOTLib.features.features_token_relations import *
+from autoBOTLib.features.features_contextual import *
 
 import string
 import re
@@ -50,16 +51,6 @@ except:
     def PerceptronTagger():
         return 0
 
-
-global contextual_feature_library
-
-try:
-    from autoBOTLib.features.features_contextual import *
-    contextual_feature_library = True
-
-except:
-    contextual_feature_library = False
-
 global feature_presets
 feature_presets = {}
 
@@ -548,6 +539,7 @@ def get_features(df_data,
                                 ('normalize', Normalizer(norm=normalization_norm))]))
         }
 
+
         if isinstance(representation_type, str):
 
             ## representation_type is pre-set
